@@ -4,30 +4,31 @@ import certifi
 from qase.api_client_v1 import ApiClient, ProjectsApi, Project, EnvironmentsApi, RunsApi, AttachmentsApi, \
     AttachmentGet, RunCreate, ResultsApi, ResultcreateBulk
 from qase.api_client_v1.configuration import Configuration
-from .. import ConfigManager, Logger
+from .. import Logger
 from .base_api_client import BaseApiClient
 from ..exceptions.reporter import ReporterException
 from ..models import Attachment, Result, Step
+from ..models.config.qaseconfig import QaseConfig
 from ..models.step import StepType
 
 
 class ApiV1Client(BaseApiClient):
-    def __init__(self, config: ConfigManager, logger: Logger):
+    def __init__(self, config: QaseConfig, logger: Logger):
         self.logger = logger
         self.config = config
 
         try:
             self.logger.log_debug("Preparing API client")
             configuration = Configuration()
-            configuration.api_key['TokenAuth'] = self.config.get('testops.api.token')
+            configuration.api_key['TokenAuth'] = self.config.testops.api.token
             configuration.ssl_ca_cert = certifi.where()
-            host = self.config.get('testops.api.host', 'qase.io')
-            if self.config.get('testops.api.enterprise', False, bool):
-                configuration.host = f'https://api-{host}/v1'
-                self.web = f'https://{host}'
-            else:
+            host = self.config.testops.api.host
+            if host == 'qase.io':
                 configuration.host = f'https://api.{host}/v1'
                 self.web = f'https://app.{host}'
+            else:
+                configuration.host = f'https://api-{host}/v1'
+                self.web = f'https://{host}'
 
             self.client = ApiClient(configuration)
             self.logger.log_debug("API client prepared")
@@ -165,8 +166,19 @@ class ApiV1Client(BaseApiClient):
         if result.get_field('layer'):
             case_data["layer"] = result.get_field('layer')
 
+        suite = None
         if result.get_suite_title():
-            case_data["suite_title"] = "\t".join(result.get_suite_title().split("."))
+            suite = "\t".join(result.get_suite_title().split("."))
+
+        if result.get_field('suite'):
+            suite = result.get_field('suite')
+
+        root_suite = self.config.root_suite
+        if root_suite:
+            suite = f"{root_suite}\t{suite}"
+
+        if suite:
+            case_data["suite_title"] = suite
 
         result_model = {
             "status": result.execution.status,
@@ -176,18 +188,15 @@ class ApiV1Client(BaseApiClient):
             "attachments": [attach.hash for attach in attached],
             "steps": steps,
             "param": result.params,
-            "defect": self.config.get('testops.defect', False, bool),
+            "param_groups": result.param_groups,
+            "defect": self.config.testops.defect,
+            "case": case_data
         }
 
         test_ops_id = result.get_testops_id()
 
         if test_ops_id:
             result_model["case_id"] = test_ops_id
-            result_model["case"] = None
-            return result_model
-
-        result_model["case_id"] = None
-        result_model["case"] = case_data
 
         self.logger.log_debug(f"Prepared result: {result_model}")
 
